Index: src/heap/gc-tracer.h |
diff --git a/src/heap/gc-tracer.h b/src/heap/gc-tracer.h |
index ca144b24b4801a808c1cbcfb77544b582dbd0cf9..0a013809e76e5df4856d76e5aadd61581b280f4c 100644 |
--- a/src/heap/gc-tracer.h |
+++ b/src/heap/gc-tracer.h |
@@ -141,15 +141,15 @@ class GCTracer { |
// Default constructor leaves the event uninitialized. |
AllocationEvent() {} |
- AllocationEvent(double duration, intptr_t allocation_in_bytes); |
+ AllocationEvent(double duration, size_t allocation_in_bytes); |
- // Time spent in the mutator during the end of the last garbage collection |
- // to the beginning of the next garbage collection. |
+ // Time spent in the mutator during the end of the last sample to the |
+ // beginning of the next sample. |
double duration_; |
- // Memory allocated in the new space during the end of the last garbage |
- // collection to the beginning of the next garbage collection. |
- intptr_t allocation_in_bytes_; |
+ // Memory allocated in the new space during the end of the last sample |
+ // to the beginning of the next sample |
+ size_t allocation_in_bytes_; |
}; |
@@ -296,7 +296,7 @@ class GCTracer { |
void Stop(GarbageCollector collector); |
// Log an allocation throughput event. |
- void AddNewSpaceAllocationTime(double duration, intptr_t allocation_in_bytes); |
+ void SampleNewSpaceAllocation(double current_ms, size_t counter_bytes); |
void AddContextDisposalTime(double time); |
@@ -380,7 +380,7 @@ class GCTracer { |
// Allocation throughput in the new space in bytes/millisecond. |
// Returns 0 if no events have been recorded. |
- intptr_t NewSpaceAllocationThroughputInBytesPerMillisecond() const; |
+ size_t NewSpaceAllocationThroughputInBytesPerMillisecond() const; |
// Computes the context disposal rate in milliseconds. It takes the time |
// frame of the first recorded context disposal to the current time and |
@@ -485,9 +485,8 @@ class GCTracer { |
// all sweeping operations performed on the main thread. |
double cumulative_sweeping_duration_; |
- // Holds the new space top pointer recorded at the end of the last garbage |
- // collection. |
- intptr_t new_space_top_after_gc_; |
+ double new_space_allocation_time_ms_; |
Hannes Payer (out of office)
2015/05/12 17:04:17
Please describe the added fields.
ulan
2015/05/18 12:45:51
Done.
|
+ size_t new_space_allocation_counter_bytes_; |
// Counts how many tracers were started without stopping. |
int start_counter_; |